@@ -1,7 +1,8 @@
-from suds.sax.element import Element
+from django.conf import settings
+from exacttarget import constants
 from suds.client import Client
+from suds.sax.element import Element
 from suds.wsse import Security, UsernameToken
-from exacttarget import client, constants
 
 class PartnerAPI(object):
     """
@@ -12,9 +13,11 @@ class PartnerAPI(object):
         internal_oauth_token
     """
     def __init__(self, internal_oauth_token):
-        # TODO use a clone instead of creating a client everytime
-        # self.client = client.clone() ==> not working properly in suds==0.4
         self.client = Client(settings.EXACTTARGET_SOAP_WSDL_URL)
+        # Make easy the access to the types
+        self.valid_types = []
+        for valid_type in self.client.sd[0].types:
+            self.valid_types.append(valid_type[0].name)
         # Add the default Security in the header
         security = Security()
         token = UsernameToken('*', '*')
@@ -22,12 +25,20 @@ class PartnerAPI(object):
         self.client.set_options(wsse=security)
         # Add oAuth token to SOAP header.
         ns = (None, constants.OAUTH_HEADER_URL)
-        oauth_header = Element("oAuth", ns=ns);
+        oauth_header = Element("oAuth", ns=ns)
         oauth_element = Element("oAuthToken")
         oauth_element.setText(internal_oauth_token)
-        oauth_header.append(oauth_element);
+        oauth_header.append(oauth_element)
         self.client.set_options(soapheaders=oauth_header)
 
+
+    def __getattribute__(self, name):
+        if name != 'valid_types' and name in self.valid_types:
+            # if the attribute is one of the Types
+            return self.client.factory.create(name)
+        else:
+            return super(PartnerAPI, self).__getattribute__(name)
+
     def create(self, options, api_objects, request_id=None, overall_status=None):
         """
         """
